==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/CastCheckEliminator.h <==
// public class soot.jimple.toolkits.pointer.CastCheckEliminator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1eb1427d60e7b1b9 soot_jimple_toolkits_pointer_CastCheckEliminator
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 6279fcb5fd9bedca soot_toolkits_scalar_BranchedFlowAnalysis
// @dep_class 1296f6ac3f04ebc9 soot_toolkits_scalar_ForwardBranchedFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardBranchedFlowAnalysis

#include "soot/toolkits/scalar/ForwardBranchedFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_pointer_CastCheckEliminator_H_
#define _JC_soot_jimple_toolkits_pointer_CastCheckEliminator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object;
struct _jc_soot_toolkits_graph_BriefUnitGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_refs	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$refs	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$nonrefs	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vmethods	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtable	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$_init$3a2189d1be03b84a(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_soot_toolkits_graph_BriefUnitGraph$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *);
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$flowThrough$cc434845b7f2ea5b(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$makeInitialSet$41168ea9c5295a72(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *);
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *);
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$tagCasts$0ef0782de41dae3a(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$flowThrough$cc434845b7f2ea5b;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$makeInitialSet$41168ea9c5295a72;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$newInitialFlow$8126aa62e2c0e28e;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$tagCasts$0ef0782de41dae3a;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *);
	void	(*flowThrough$cc434845b7f2ea5b)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
	void	(*makeInitialSet$41168ea9c5295a72)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *);
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *);
	void	(*tagCasts$0ef0782de41dae3a)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods	soot_toolkits_scalar_BranchedFlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vmethods	soot_jimple_toolkits_pointer_CastCheckEliminator;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_refs {
	struct _jc_object	*unitToKill;
	struct _jc_object	*unitToGenFallThrough;
	struct _jc_object	*unitToGenBranch;
	struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object	*emptySet;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$refs {
    _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_refs	soot_jimple_toolkits_pointer_CastCheckEliminator;
    _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
    _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_nonrefs	soot_jimple_toolkits_pointer_CastCheckEliminator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object {
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_CastCheckEliminator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_CastCheckEliminator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/CastCheckEliminator.h <==
// public class soot.jimple.toolkits.pointer.CastCheckEliminator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1eb1427d60e7b1b9 soot_jimple_toolkits_pointer_CastCheckEliminator
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 6279fcb5fd9bedca soot_toolkits_scalar_BranchedFlowAnalysis
// @dep_class 1296f6ac3f04ebc9 soot_toolkits_scalar_ForwardBranchedFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardBranchedFlowAnalysis

#include "soot/toolkits/scalar/ForwardBranchedFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_pointer_CastCheckEliminator_H_
#define _JC_soot_jimple_toolkits_pointer_CastCheckEliminator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object;
struct _jc_soot_toolkits_graph_BriefUnitGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_refs	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$refs	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$nonrefs	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vmethods	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtable	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$_init$3a2189d1be03b84a(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_soot_toolkits_graph_BriefUnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$flowThrough$cc434845b7f2ea5b(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$makeInitialSet$41168ea9c5295a72(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method$tagCasts$0ef0782de41dae3a(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$flowThrough$cc434845b7f2ea5b;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$makeInitialSet$41168ea9c5295a72;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$newInitialFlow$8126aa62e2c0e28e;
extern _jc_method _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$method_info$tagCasts$0ef0782de41dae3a;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *) _JC_JCNI_ATTR;
	void	(*flowThrough$cc434845b7f2ea5b)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*makeInitialSet$41168ea9c5295a72)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *) _JC_JCNI_ATTR;
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *) _JC_JCNI_ATTR;
	void	(*tagCasts$0ef0782de41dae3a)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods	soot_toolkits_scalar_BranchedFlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vmethods	soot_jimple_toolkits_pointer_CastCheckEliminator;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_refs {
	struct _jc_object	*unitToKill;
	struct _jc_object	*unitToGenFallThrough;
	struct _jc_object	*unitToGenBranch;
	struct _jc_soot_jimple_toolkits_pointer_LocalTypeSet$object	*emptySet;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$refs {
    _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_refs	soot_jimple_toolkits_pointer_CastCheckEliminator;
    _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardBranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardBranchedFlowAnalysis;
    _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$sub_nonrefs	soot_jimple_toolkits_pointer_CastCheckEliminator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$object {
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_CastCheckEliminator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$vtype _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_CastCheckEliminator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_CastCheckEliminator$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_CastCheckEliminator_H_ */
